pub enum SolverStatus {
NotSolving,
SolvingActive,
TerminatingEarly,
SolvingScheduled,
Unknown,
}Expand description
The state of the solver for a given job.
Variants
NotSolving
The solver is idle and not working on the job.
SolvingActive
The solver is actively working on the job.
TerminatingEarly
The solver is winding down and terminating early.
SolvingScheduled
The job is queued and scheduled to start solving.
Unknown
Any status value not otherwise recognized.