pub struct FieldServiceClient { /* private fields */ }Expand description
Client for the field service optimization API.
Implementations
Sourceimpl FieldServiceClient
impl FieldServiceClient
Sourcepub async fn start(
&self,
request: &FieldServiceRequest,
) -> Result<FieldServiceStartResponse>
pub async fn start( &self, request: &FieldServiceRequest, ) -> Result<FieldServiceStartResponse>
Starts a new field service optimization job.
Sourcepub async fn get_status(&self, job_id: &str) -> Result<SolverStatusResponse>
pub async fn get_status(&self, job_id: &str) -> Result<SolverStatusResponse>
Gets the status of a field service optimization job.
Sourcepub async fn get_result(
&self,
job_id: &str,
) -> Result<FieldServiceResultResponse>
pub async fn get_result( &self, job_id: &str, ) -> Result<FieldServiceResultResponse>
Gets the result of a completed field service optimization job.
Sourcepub async fn analyze(&self, job_id: &str) -> Result<Value>
pub async fn analyze(&self, job_id: &str) -> Result<Value>
Gets analysis for a completed field service optimization job.
Sourcepub async fn start_and_wait_for_completion(
&self,
request: &FieldServiceRequest,
poll_interval_ms: u64,
max_attempts: u32,
) -> Result<FieldServiceResultResponse>
pub async fn start_and_wait_for_completion( &self, request: &FieldServiceRequest, poll_interval_ms: u64, max_attempts: u32, ) -> Result<FieldServiceResultResponse>
Starts a job and polls until it completes.
Sourcepub async fn wait_for_completion(
&self,
job_id: &str,
poll_interval_ms: u64,
max_attempts: u32,
) -> Result<FieldServiceResultResponse>
pub async fn wait_for_completion( &self, job_id: &str, poll_interval_ms: u64, max_attempts: u32, ) -> Result<FieldServiceResultResponse>
Polls for job status until the solver finishes or max_attempts is reached.